/* BdfServer - Copyright (c) 2012-2015 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.tools.interaction;

import fr.exemole.bdfserver.api.exportation.table.FicheTableParameters;
import fr.exemole.bdfserver.tools.exportation.table.FicheTableParametersBuilder;
import net.mapeadores.util.logging.ErrorMessageException;
import net.mapeadores.util.request.RequestMap;
import net.mapeadores.util.text.StringUtils;


/**
 *
 * @author Vincent Calame
 */
public final class FicheTableParametersParser {

    public final static String WITH_PARAMNAME = "with";
    public final static String PATTERNMODE_PARAMNAME = "patternmode";

    private FicheTableParametersParser() {

    }

    public static FicheTableParameters parse(RequestMap requestMap) throws ErrorMessageException {
        FicheTableParametersBuilder ficheTableParametersBuilder = new FicheTableParametersBuilder();
        String[] values = requestMap.getParameterValues(WITH_PARAMNAME);
        if (values != null) {
            for (String value : values) {
                String[] tokens = StringUtils.getTokens(value, ',', StringUtils.EMPTY_EXCLUDE);
                for (String token : tokens) {
                    ficheTableParametersBuilder.putWith(token);
                }
            }
        }
        String patternMode = requestMap.getParameter(PATTERNMODE_PARAMNAME);
        if (patternMode != null) {
            try {
                ficheTableParametersBuilder.setPatternMode(FicheTableParameters.checkPatternMode(patternMode));
            } catch (IllegalArgumentException iae) {
                throw new ErrorMessageException("_ error.unknown.patternmode", patternMode);
            }
        }
        return ficheTableParametersBuilder.toFicheTableParameters();
    }

}
